# meme

**DOI:** [10.5281/zenodo.14931137](https://doi.org/10.5281/zenodo.14931137)

## Available Versions
- **Version 5.5.3**
  - [Download](https://zenodo.org/record/14931138/files/meme_5.5.3.img)
  - **MD5:** `d70cf730bc06bc7bd47fc676f3dfac5e`
  - **DOI:** [10.5281/zenodo.14931138](https://doi.org/10.5281/zenodo.14931138)
  - **Size:** 594.84 MB
  - **Binaries:** 0 available

## Binaries (19 total)

```ame dreme fimo glam2scan mast meme momo sea streme tomtom centrimodust glam2 gomo mcast meme-chip purge spamo tgene xstreme```
